#undef PACKAGE
#undef VERSION
#undef WITH_PYTHON
#undef USE_XIM
#undef HAVE_LIBSM
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY
#undef ENABLE_NLS
